@@ -5,6 +5,7 @@ setClass(Class = "OutlierDC", representation(
 							formula = "Formula",
 							raw.data = "data.frame",
 							refined.data = "data.frame",
+							outlier.data = "data.frame",
 							coefficients ="data.frame",
 							fitted.mat = "matrix",
 							score = "vector",
@@ -15,7 +16,8 @@ setClass(Class = "OutlierDC", representation(
 							n.outliers = "integer",
 							method = "character",
 							rq.model = "character",
-							k = "numeric",
-							UB = "numeric",
-							LB = "numeric")
+							k_r = "numeric",
+							k_b = "numeric",
+							bound = "character",
+							k_s = "numeric")
 )
